# pyvmomi-tools
Extra tools for pyvmomi to make using it easier.

Much of this code was repurposed from the community samples.

## How to use
To install this package, download it locally and install by running `pip install .` in this project repository to install it locally on your machine

## Contributing
If you want to contribue go ahead, the more tools the merrier! If I do not see your pull request, email me at [blaketur@buffalo.edu](mailto:blaketur@buffalo.edu) or [ubnetdef@buffalo.edu](mailto:ubnetdef@buffalo.edu)